@@ -5,13 +5,13 @@ set -eu
 function annotate_crd() {
   script='/^metadata:/a\
 \ \ annotations:\
-\ \ \ \ exclude.release.openshift.io/internal-opernshift-hosted: "true"'
+\ \ \ \ exclude.release.openshift.io/internal-openshift-hosted: "true"'
   input="${1}"
   output="${2}"
   sed -e "${script}" "${input}" > "${output}"
 }
 
-go run ./vendor/sigs.k8s.io/controller-tools/cmd/controller-gen crd paths=./pkg/apis/...
+go run ./vendor/sigs.k8s.io/controller-tools/cmd/controller-gen crd:crdVersions=v1 paths=./pkg/apis/...
 
 echo "Copying generated CRDs"
 annotate_crd config/crd/autoscaling.openshift.io_clusterautoscalers.yaml install/01_clusterautoscaler.crd.yaml
